import { ParticleSystem } from './ParticleSystem';
import { Mesh, ShaderMaterial, BufferGeometry, Material, Layers } from 'three';
export interface VFXBatchSettings {
    instancingGeometry: BufferGeometry;
    material: Material;
    uTileCount: number;
    vTileCount: number;
    renderMode: RenderMode;
    renderOrder: number;
    layers: Layers;
}
export declare enum RenderMode {
    BillBoard = 0,
    StretchedBillBoard = 1,
    Mesh = 2,
    Trail = 3
}
export declare abstract class VFXBatch extends Mesh {
    type: string;
    systems: Set<ParticleSystem>;
    material: ShaderMaterial;
    settings: VFXBatchSettings;
    protected maxParticles: number;
    protected constructor(settings: VFXBatchSettings);
    addSystem(system: ParticleSystem): void;
    removeSystem(system: ParticleSystem): void;
    abstract setupBuffers(): void;
    abstract expandBuffers(target: number): void;
    abstract rebuildMaterial(): void;
    abstract update(): void;
    abstract dispose(): void;
}
